==> fvwmconf_0.18-1.tar.gz: fvwmconf-0.18/lib/main.pl <==
############################################################################################

sub main_window {

$MW = new MainWindow;

my $m0 = make_help_dismiss('NoDismiss',$MW,
			   'File:main' );


#my $m0 = $MW->Frame(@fracon,);
#$m0->pack(-side => 'top', -fill => 'x');
my $mf = $m0->Menubutton(
@menbutcon,
			 -text      => 'File',
			 );
$mf->pack(-side => 'left');

$mf->command(
	     -label => 'Save',
#	     -textvariable => \$CONFFILE,
	     -command => sub { set_saved(); write_all_variables(); write_state;}
	     );
$mf->command(
	     -label => 'Save As ...',
	     -command => \&save_as
	     );

$mf->command(
	     -label => 'Re-Load',
	     -command => sub 
	     {return unless is_saved() or query_save(); 
	      clear_config();
	      read_all_variables;
	      load_all_to_panel();
	      execute_all(0);
	      recapture();}
	     );
$mf->command(
	     -label => 'Load',
	     -command => \&change_configuration
	     );

$mf->separator;

$mf->command(
	     -label => 'Re-execute',
	     -command => sub {execute_all(0);
	      recapture();}

	     );
$mf->command(
	     -label => 'Clear',
	     -command => sub {
		 return unless is_saved() or query_save();
		 clear_config(); reset_decors(); reset_fvwm();
		 create_style_variables('*');
		 initialize_style('*');
		 create_decor_variables('default');	 
	       execute_all(0);recapture();}
	     );		
$mf->separator;

$mf->command(
	     -label => 'Write',
	     -command => \&dump_fvwm_commands
	     );
$mf->command(
	     -label => 'Read',
	     -command => \&read_fvwm2rc_query
	     );
	
$mf->separator;

$mf->command(
	     -activebackground => 'yellow',
	     -label       => 'Restart FvwmConf', 
	     -command     => \&restart_fvwmconf_exit,
	     );
$mf->command(
	     -activebackground => 'yellow',
	     -label       => 'Exit FvwmConf', 
	     -command     => \&close_command,
	     );



$mf->command(
	     -label => 'Restart Fvwm',
	     -activebackground => 'yellow',
	     -command => sub { 
#		 return unless is_saved() or query_save();
#		 write_state();
		 restart_fvwm_exit();}
	     );

$mf->separator;
$mf->command(
	     -label => 'Quit Fvwm',
	     -activebackground => 'red',
	     -command => sub { 
#		 return unless is_saved() or query_save();
		 exit_fvwm_exit();}
	     );



$m1 = $m0->Menubutton(
@menbutcon,
			 -text      => 'Configure',
			 );

$m1->pack(-side => 'left');
$m1->command(
	     -label => 'Images',
	     -command => \&set_images);
$m1->command(
	     -label => 'Fonts',
	     -command => \&set_fonts);

$m1->command(
	     -label => 'Colors',
	     -command => \&color_tool);

$m1->separator;

$m1->command(
	     -label => 'Global',
	     -command => \&set_global);


#$m1->command(
#	     -label => 'Sty./Dec.',
#	     -command => sub {set_style();set_decor()});

$m1->command(
	     -label => 'Style',
	     -command => \&set_style);


$m1->command(
	     -label => 'Decor',
	     -command => \&set_decor);

$m1->command(
	     -label => 'Buttons',
	     -command => \&set_buttons);

$m1->separator;

#$pm = $m1->Menubutton(
#		      -text => 'Modules');
#$pm->pack(-side=>'left');

$m1->command(
	     -label => 'Pager',
	     -command => \&set_pager);

$m1->command(
	     -label => 'WinList',
	     -command => \&set_winlist);
#$m1->command(
#	     -label => '',
#	     -command => );

$m2 = $m0->Menubutton( 
@menbutcon,
		 -text => 'Extra' ,

);
$m2->pack(-side => 'right');

$m2->command( -label =>'Error Log',-command => \&errlog);

$m2->command(
	     -label => 'Command Entry',
	     -command => \&command_line);
$m2->command(
	     -label => 'Command Editor',
	     -command => \&command_edit);

$m2->command( -label => 'Debug Box',
	     -command =>  \&debug_box
	     );

$m2->command( -label => 'Mail Comments',
	     -command =>  \&mail
	     );

$m0->Label(@labcon,-bd=>1,
		 -textvariable => \$CONFFILE
		 )->pack;




$topf = $MW->Frame(@fracon,)->pack(-side => 'top',-fill=>'x');

$update = $topf->Button( 
@butcon2,
-text => 'UpdateDecor',
			-command =>  [\&send_command,'UpdateDecor']);
$update->pack(-side => 'left');

$topf->Button(@butcon2,-text => 'About',
	      -command=>sub{display_help ("File:About" ) })
    ->pack(-side=>'left',@EF);

$recap = $topf->Button(
@butcon2,
 -text => 'Recapture',
			-command =>  [\&send_command,'Recapture']);
$recap->pack(-side => 'right');




} ## end main_window

##############################################################

sub restart_fvwm_exit {
    write_state();
    if (is_saved() or query_save()) {
	   send_command 'Restart';
    }
    mysleep(.5);
    exit();
}
    
sub restart_fvwmconf_exit {
    write_state(); mysleep(.1);
     if (is_saved() or query_save()) {
	   send_command 'FvwmConf';   # Duh ! this already kills the old one
      mysleep($SLEEP); 
      endModule($FARGS{OFD});$MW->destroy;
	#   mysleep($SLEEP); 
    }
}  


sub exit_fvwm_exit {

    if (is_saved() or query_save()) {
    write_state();
	mysleep($SLEEP);send_command 'Quit';
    }
    mysleep(.5);
    exit();
}


#########################################################################
1;

==> fvwmconf_0.19-5.tar.gz: fvwmconf-0.19/lib/main.pl <==
############################################################################################

sub main_window {

$MW = new MainWindow;

$MW->configure(-title=>"FvwmConf $VERSION");

my $m0 = make_help_dismiss('NoDismiss',$MW,
			   'File:main' );


#my $m0 = $MW->Frame(@fracon,);
#$m0->pack(-side => 'top', -fill => 'x');
my $mf = $m0->Menubutton(
@menbutcon,
			 -text      => 'File',
			 );
$mf->pack(-side => 'left');

$mf->command(
	     -label => 'Save',
#	     -textvariable => \$CONFFILE,
	     -command => sub { set_saved(); write_all_variables(); write_state;}
	     );
$mf->command(
	     -label => 'Save As ...',
	     -command => \&save_as
	     );

$mf->command(
	     -label => 'Re-Load',
	     -command => sub 
	     {return unless is_saved() or query_save(); 
	      clear_config();
	      read_all_variables;
	      load_all_to_panel();
	      execute_all(0);
	      recapture();}
	     );
$mf->command(
	     -label => 'Load',
	     -command => \&change_configuration
	     );

$mf->separator;

$mf->command(
	     -label => 'Re-execute',
	     -command => sub {execute_all(0);
	      recapture();}

	     );
$mf->command(
	     -label => 'Clear',
	     -command => sub {
		 return unless is_saved() or query_save();
		 clear_config(); reset_decors(); reset_fvwm();
		 create_style_variables('*');
		 initialize_style('*');
		 create_decor_variables('default');	 
	       execute_all(0);recapture();}
	     );		
$mf->separator;

$mf->command(
	     -label => 'Write',
#	     -command => \&dump_fvwm_commands
	     -command => \&write_fvwm2rc_query
	     );
$mf->command(
	     -label => 'Read',
	     -command => \&read_fvwm2rc_query
	     );
	
$mf->separator;

$mf->command(
	     -activebackground => 'yellow',
	     -label       => 'Restart FvwmConf', 
	     -command     => \&restart_fvwmconf_exit,
	     );
$mf->command(
	     -activebackground => 'yellow',
	     -label       => 'Exit FvwmConf', 
	     -command     => \&close_command,
	     );



$mf->command(
	     -label => 'Restart Fvwm',
	     -activebackground => 'yellow',
	     -command => sub { 
#		 return unless is_saved() or query_save();
#		 write_state();
		 restart_fvwm_exit();}
	     );

$mf->separator;
$mf->command(
	     -label => 'Quit Fvwm',
	     -activebackground => 'red',
	     -command => sub { 
#		 return unless is_saved() or query_save();
		 exit_fvwm_exit();}
	     );



$m1 = $m0->Menubutton(
@menbutcon,
			 -text      => 'Configure',
			 );

$m1->pack(-side => 'left');
$m1->command(
	     -label => 'Images',
	     -command => \&set_images);
$m1->command(
	     -label => 'Fonts',
	     -command => \&set_fonts);

$m1->command(
	     -label => 'Colors',
	     -command => \&color_tool);

$m1->separator;

$m1->command(
	     -label => 'Global',
	     -command => \&set_global);


#$m1->command(
#	     -label => 'Sty./Dec.',
#	     -command => sub {set_style();set_decor()});

$m1->command(
	     -label => 'Style',
	     -command => \&set_style);


$m1->command(
	     -label => 'Decor',
	     -command => \&set_decor);

$m1->command(
	     -label => 'Buttons',
	     -command => \&set_buttons);



$m1->command(
	     -label => 'Menus',
	     -command => \&set_menus);


$m1->separator;


#$pm = $m1->Menubutton(
#		      -text => 'Modules');
#$pm->pack(-side=>'left');

$m1->command(
	     -label => 'Pager',
	     -command => \&set_pager);

$m1->command(
	     -label => 'WinList',
	     -command => \&set_winlist);
#$m1->command(
#	     -label => '',
#	     -command => );

$m2 = $m0->Menubutton( 
@menbutcon,
		 -text => 'Extra' ,

);
$m2->pack(-side => 'right');

$m2->command( -label =>'Error Log',-command => \&errlog);

$m2->command(
	     -label => 'Command Entry',
	     -command => \&command_line);
$m2->command(
	     -label => 'Command Editor',
	     -command => \&command_edit);

$m2->command( -label => 'Debug Box',
	     -command =>  \&debug_box
	     );

$m2->command( -label => 'Mail Comments',
	     -command =>  \&mail
	     );

$m0->Label(@labcon,-bd=>1,
		 -textvariable => \$CONFFILE
		 )->pack;




$topf = $MW->Frame(@fracon,)->pack(-side => 'top',-fill=>'x');

$update = $topf->Button( 
@butcon2,
-text => 'UpdateDecor',
			-command =>  [\&send_command,'UpdateDecor']);
$update->pack(-side => 'left');

$topf->Button(@butcon2,-text => 'About',
	      -command=>sub{display_help ("File:About" ) })
    ->pack(-side=>'left',@EF);

$recap = $topf->Button(
@butcon2,
 -text => 'Recapture',
			-command =>  [\&send_command,'Recapture']);
$recap->pack(-side => 'right');




} ## end main_window

##############################################################

sub restart_fvwm_exit {
    write_state();
    if (is_saved() or query_save()) {
	   send_command 'Restart';
    }
    mysleep(.5);
    exit();
}
    
sub restart_fvwmconf_exit {
    write_state(); mysleep(.1);
     if (is_saved() or query_save()) {
	   send_command 'FvwmConf';   # Duh ! this already kills the old one
      mysleep($SLEEP); 
      endModule($FARGS{OFD});$MW->destroy;
	#   mysleep($SLEEP); 
    }
}  


sub exit_fvwm_exit {
    write_state();
    if (is_saved() or query_save()) {
	mysleep($SLEEP);send_command 'Quit';
    }
    mysleep(.5);
    exit();
}


#########################################################################
1;
